@@ -274,7 +274,7 @@ print_search_path_cb (GOptionGroup *common_options,
   char eol = '\n';
 
   context = g_option_context_new (NULL);
-  g_option_context_add_group (context, common_options);
+  g_option_context_add_group (context, g_option_group_ref (common_options));
   g_option_context_set_summary (context,
       "Print the search path for GIR XML files.");
 
@@ -347,7 +347,7 @@ find_cb (GOptionGroup *common_options,
   char eol = '\n';
 
   context = g_option_context_new ("NAMESPACE-VER [NAMESPACE-VER…]");
-  g_option_context_add_group (context, common_options);
+  g_option_context_add_group (context, g_option_group_ref (common_options));
   g_option_context_add_main_entries (context, entries, NULL);
   g_option_context_set_summary (context,
       "Print the paths to the GIR XML files for the given namespaces.");
